# SaraikiNLP: The Python NLP Framework for Saraiki Language Research

<div align="center">
<a href="https://github.com/SaraikiNLP/SaraikiNLP"><img src="https://img.shields.io/badge/Github-SaraikiNLP-blue?logo=github"/></a>
<a href="https://huggingface.co/SaraikiNLP"><img src="https://img.shields.io/badge/Hugging%20Face-SaraikiNLP-yellow?logo=huggingface"/></a>
<a href="https://github.com/SaraikiNLP/SaraikiNLP/graphs/contributors"><img src="https://img.shields.io/github/contributors/SaraikiNLP/SaraikiNLP.svg" /></a>
<a href="https://pepy.tech/project/SaraikiNLP"><img src="https://pepy.tech/badge/SaraikiNLP" /></a>
<a href="https://github.com/SaraikiNLP/SaraikiNLP/blob/master/LICENSE"><img src="https://img.shields.io/badge/license-MIT-blue.svg" /></a>
</div>

<img src="https://raw.githubusercontent.com/SaraikiNLP/SaraikiNLP/main/Images/SaraikiNLP_stylized_logo.jpg" alt="Saraiki NLP logo with stylized script and the letters 'NLP' below, framed with traditional decorative borders." style="width:100%; height:100%;">

## Table of Contents

1. [Introduction](#introduction)
2. [Why Saraiki?](#why-saraiki)
   - [About the Saraiki Language](#about-the-saraiki-language)
   - [Why Should One Work on Saraiki NLP?](#why-should-one-work-on-saraiki-nlp)
   - [The Goal of SaraikiNLP](#the-goal-of-saraikinlp)
3. 🎁 [Resources](#resources-)
4. [Intended Audience](#intended-audience)
5. [Features](#features)
6. [Installation](#installation)
7. [Documentation](#documentation)
8. [Contributing](#contributing)
9. [License](#copyright-and-license)
<br>
<img src="https://raw.githubusercontent.com/SaraikiNLP/SaraikiNLP/main/Images/ajrak_line.png" alt="Saraiki Ajrak Border" style="width:100%; height:20%;">

## Introduction

**SaraikiNLP** is the world's first and fundamental **Python framework** for **Saraiki language research**. It comes with **basic NLP functions** to help researchers, students, and anyone interested in Saraiki NLP work.

<br>
<img src="https://raw.githubusercontent.com/SaraikiNLP/SaraikiNLP/main/Images/ajrak_line.png" alt="Saraiki Ajrak Border" style="width:100%; height:20%;">

## Why Saraiki?

### About the Saraiki Language

**Saraiki (skr)** is an **Indo-Aryan** language spoken by over 25–30 million people, primarily in Pakistan. It is spoken in **Southern Punjab** in cities like **Multan**, **Bahawalpur**, **Dera Ghazi Khan**, and **Rahim Yar Khan**, and extends into parts of **Sindh**, **Balochistan**, and **Khyber Pakhtunkhwa**. Despite its rich linguistic and cultural heritage, Saraiki remains underrepresented in NLP and computational research.

### Why Should One Work on Saraiki NLP?

Despite having millions of speakers, Saraiki still lacks digital resources, computational tools, and NLP support. Major challenges include:

- **Limited Text Datasets** – Few machine-readable corpora are available.
- **Minimal NLP Research** – There is less work on tokenization, lemmatization, named entity recognition (NER), or speech recognition.
- **No Official Status** – Unlike Urdu or Punjabi, Saraiki lacks mainstream software support in AI and ML applications.

### The Goal of SaraikiNLP

The **SaraikiNLP project** aims to:

- **Developing Core NLP Tools** – Implement normalization, tokenization, lemmatization, stemming, and NER models.
- **Promote Saraiki Research** – Increase awareness and support for research in this low resource language.

<br>
<img src="https://raw.githubusercontent.com/SaraikiNLP/SaraikiNLP/main/Images/ajrak_line.png" alt="Saraiki Ajrak Border" style="width:100%; height:20%;">

## Resources 🎁

| Link | Description |
| --------------- | -------------------------------------------------------------- |
| [Saraiki Alphabets]  | Saraiki alphabets. |
| [Saraiki Counting]    | Saraiki counting. |
| [Saraiki Months]     | Saraiki month names with Urdu and English counterparts. |
| [Saraiki Week Days]  | Saraiki day names with counterparts. |
| [Current Saraiki Research] | Current research being done on Saraiki language. |


[Saraiki Alphabets]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Resources/saraiki_alphabets.md
[Saraiki Counting]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Resources/saraiki_counting.md
[Saraiki Months]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Resources/saraiki_months.md
[Saraiki Week Days]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Resources/saraiki_week_days.md
[Current Saraiki Research]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Resources/saraiki_research.md

<br>
<img src="https://raw.githubusercontent.com/SaraikiNLP/SaraikiNLP/main/Images/ajrak_line.png" alt="Saraiki Ajrak Border" style="width:100%; height:20%;">

## Intended Audience

- **Science/Research:** For researchers and linguists experimenting with Saraiki language data.
- **Developers:** To help build Saraiki applications with less effort.
- **Education:** Providing resources and tools for students interested in Saraiki language research.

<br>
<img src="https://raw.githubusercontent.com/SaraikiNLP/SaraikiNLP/main/Images/ajrak_line.png" alt="Saraiki Ajrak Border" style="width:100%; height:20%;">

## Features 

- ✔️ Normalization
- ✔️ Preprocessing
- 🚧 Tokenization
- 🚧 Stemming
- 🚧 Lemmatization

<br>
<img src="https://raw.githubusercontent.com/SaraikiNLP/SaraikiNLP/main/Images/ajrak_line.png" alt="Saraiki Ajrak Border" style="width:100%; height:20%;">

## Installation

Using **pip**, SaraikiNLP can be easily installed:

```bash
pip install SaraikiNLP
```

<br>
<img src="https://raw.githubusercontent.com/SaraikiNLP/SaraikiNLP/main/Images/ajrak_line.png" alt="Saraiki Ajrak Border" style="width:100%; height:20%;">

## Documentation


| Link | Description | Free Notebook (Colab) |
| --------------- | ------------------------------ | -------------------------------- |
| [Normalization]  | Our functions and usage examples for normalization. | [▶️ Start Now](https://colab.research.google.com/github/SaraikiNLP/SaraikiNLP/blob/main/Notebooks/normalization.ipynb) |
| [Preprocessing]    | Functions SaraikiNLP provides for preprocessing. | [▶️ Start Now](https://colab.research.google.com/github/SaraikiNLP/SaraikiNLP/blob/main/Notebooks/preprocessing.ipynb) |
| 🚧 [Tokenization]    | Functions for tokenization. | ⌛ Coming Soon |
| 🚧 [Stemming]    | Functions for stemming. | ⌛ Coming Soon |
| 🚧 [Lemmatization]    | Functions for lemmatization. | ⌛ Coming Soon |

[Normalization]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Documentation/normalization.md
[Preprocessing]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Documentation/preprocessing.md
[Tokenization]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Documentation/tokenization.md
[Stemming]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Documentation/stemming.md
[Lemmatization]: https://github.com/SaraikiNLP/SaraikiNLP/blob/main/Documentation/lemmatization.md

<br>
<img src="https://raw.githubusercontent.com/SaraikiNLP/SaraikiNLP/main/Images/ajrak_line.png" alt="Saraiki Ajrak Border" style="width:100%; height:20%;">

## Contributing

We welcome contributions from everyone! If you'd like to help improve **SaraikiNLP** OR if you notice any mistakes or have suggestions for improvement, feel free to:

- Open an [issue](https://github.com/SaraikiNLP/SaraikiNLP/issues)  
- Submit a [pull request](https://github.com/SaraikiNLP/SaraikiNLP/pulls)  

Your contributions are highly appreciated and make **SaraikiNLP** better for everyone. **Thank you for your interest! :-)**

<br>
<img src="https://raw.githubusercontent.com/SaraikiNLP/SaraikiNLP/main/Images/ajrak_line.png" alt="Saraiki Ajrak Border" style="width:100%; height:20%;">

## Copyright and license

Code released under the [MIT License](https://github.com/SaraikiNLP/SaraikiNLP/blob/master/LICENSE.md).